==> nagvis_1.6.4.dfsg.1.orig.tar.gz: nagvis-1.6.4.dfsg.1/share/server/core/classes/CoreModOverview.php <==
<?php
/*******************************************************************************
 *
 * CoreModOverview.php - Core Overview module to handle ajax requests
 *
 * Copyright (c) 2004-2011 NagVis Project (Contact: info@nagvis.org)
 *
 * License:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ******************************************************************************/

/**
 * @author Lars Michelsen <lars@vertical-visions.de>
 */
class CoreModOverview extends CoreModule {
    public function __construct(GlobalCore $CORE) {
        $this->sName = 'Overview';
        $this->CORE = $CORE;

        $this->aActions = Array(
            'getOverviewProperties' => 'view',
            'getOverviewMaps'       => 'view',
            'getOverviewAutomaps'   => 'view',
            'getOverviewRotations'  => 'view',
            'getObjectStates'       => 'view',
        );
    }

    public function handleAction() {
        $sReturn = '';

        if($this->offersAction($this->sAction)) {
            $OVERVIEW = new GlobalIndexPage();

            switch($this->sAction) {
                case 'getOverviewProperties':
                    $sReturn = $OVERVIEW->parseIndexPropertiesJson();
                break;
                case 'getOverviewMaps':
                    $sReturn = $OVERVIEW->parseMapsJson('map');
                break;
                case 'getOverviewAutomaps':
                    $sReturn = $OVERVIEW->parseMapsJson('automap');
                break;
                case 'getOverviewRotations':
                    $sReturn = $OVERVIEW->parseRotationsJson();
                break;
                case 'getObjectStates':
                    $aOpts = Array('i'  => MATCH_STRING_NO_SPACE);
                    $aVals = $this->getCustomOptions($aOpts);

                    $sReturn = $OVERVIEW->parseMapsJson('list', ONLY_STATE, $aVals['i']);
                break;
            }
        }

        return $sReturn;
    }
}
?>

==> nagvis_1.6.6+dfsg.1.orig.tar.gz: nagvis-1.6.6+dfsg.1/share/server/core/classes/CoreModOverview.php <==
<?php
/*******************************************************************************
 *
 * CoreModOverview.php - Core Overview module to handle ajax requests
 *
 * Copyright (c) 2004-2011 NagVis Project (Contact: info@nagvis.org)
 *
 * License:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ******************************************************************************/

/**
 * @author Lars Michelsen <lars@vertical-visions.de>
 */
class CoreModOverview extends CoreModule {
    public function __construct(GlobalCore $CORE) {
        $this->sName = 'Overview';
        $this->CORE = $CORE;

        $this->aActions = Array(
            'getOverviewProperties' => 'view',
            'getOverviewMaps'       => 'view',
            'getOverviewAutomaps'   => 'view',
            'getOverviewRotations'  => 'view',
            'getObjectStates'       => 'view',
        );
    }

    public function handleAction() {
        $sReturn = '';

        if($this->offersAction($this->sAction)) {
            $OVERVIEW = new GlobalIndexPage();

            switch($this->sAction) {
                case 'getOverviewProperties':
                    $sReturn = $OVERVIEW->parseIndexPropertiesJson();
                break;
                case 'getOverviewMaps':
                    $sReturn = $OVERVIEW->parseMapsJson('map');
                break;
                case 'getOverviewAutomaps':
                    $sReturn = $OVERVIEW->parseMapsJson('automap');
                break;
                case 'getOverviewRotations':
                    $sReturn = $OVERVIEW->parseRotationsJson();
                break;
                case 'getObjectStates':
                    $aOpts = Array('i'  => MATCH_STRING_NO_SPACE);
                    $aVals = $this->getCustomOptions($aOpts);

                    $sReturn = $OVERVIEW->parseMapsJson('list', COMPLETE, $aVals['i']);
                break;
            }
        }

        return $sReturn;
    }
}
?>
